@@ -6,7 +6,7 @@ Created on Sun Jan 17 14:02:49 2021
 """
 
 
-import CIG_edge as cig_edge
+import src.CIG_edge as cig_edge
 
 class Node():
     def __init__(self, node, lbl):
